<?php

namespace Drupal\git_issues\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;

/**
 * @package Drupal/git_issues/Controller
 */
class GitIssuesController extends ControllerBase implements ContainerInjectionInterface {
  /**
   * Plugin instance.
   *
   * @var string
   */
  protected $plugin;

  /**
   * Config instance.
   *
   * @var string
   */
  protected $gitSettings;

  /**
   * Constructs a new GitIssuesController object.
   */
  public function __construct() {
    $gitSettings = \Drupal::config('git_issues.settings');
    $activePlugin = $gitSettings->get('plugins.active');
    $activePlugin = (empty($activePlugin) && is_null($activePlugin)) ? 'gitlab' : $activePlugin;

    $this->plugin = \Drupal::service('plugin.manager.git_issues')->createInstance($activePlugin);
  }

  /**
   * Returns the list of issues for single project.
   * *.
   *
   * @return string
   *   A HTML-formatted string with the list of issues.
   */
  public function project() {
    $result = $this->plugin->getProjectIssues();

    if (!$result) {
      return $this->redirect('git_issues.admin_form');
    }
    else {
      return $result;
    }
  }

  /**
   * Returns the single issue view.
   * *.
   *
   * @return string
   *   A HTML-formatted string with the single issue view.
   */
  public function issueView($issueId) {
    return $this->plugin->getIssue($issueId);
  }

  /**
   * Change issue state.
   * *.
   */
  public function issueState($issueId, $state) {
    if (!is_null($state) && !empty($state)) {
      $this->plugin->issueChangeState($issueId, $state);
    }

    return $this->redirect('git_issues.issue.view', ['issueId' => $issueId]);
  }

  /**
   * Post issue comment.
   * *.
   */
  public function issueComment($issueId) {
    $this->plugin->postIssueComment($issueId);

    return $this->redirect('git_issues.issue.view', ['issueId' => $issueId]);
  }

  /**
   * Returns edit issue form.
   * *.
   */
  public function issueEdit($issueId) {
    $form = \Drupal::formBuilder()->getForm('Drupal\git_issues\Form\GitIssuesIssueForm', $issueId);

    return $form;
  }

  /**
   * Returns add issue form.
   * *.
   */
  public function addIssue() {
    $form = \Drupal::formBuilder()->getForm('Drupal\git_issues\Form\GitIssuesIssueForm');

    return $form;
  }

}
