<?php

namespace Drupal\git_issues\Form;

use Drupal\Core\Url;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a creation  form for the issue instance create form.
 *
 * @package Drupal/git_issues/Service
 */
class GitIssuesIssueForm extends FormBase {

  private $instance;

  /**
   *
   */
  public function getFormId() {
    // Unique ID of the form.
    return 'issueAdd';
  }

  /**
   * Constructs a GitIssuesIssueForm object.
   */
  public function __construct() {
    $this->gitSettings = \Drupal::config('git_issues.settings');
    $this->activePlugin = $this->gitSettings->get('plugins.active');
    $this->activePlugin = (empty($this->activePlugin) && is_null($this->activePlugin)) ? 'gitlab' : $this->activePlugin;

    $this->instance = \Drupal::service('plugin.manager.git_issues')->createInstance($this->activePlugin);
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $issueId = NULL) {
    if (empty($this->instance) || is_null($this->instance)) {
      $this->instance = \Drupal::service('plugin.manager.git_issues')->createInstance($this->activePlugin);
    }

    if (!is_null($issueId)) {
      $vars = [
        'action' => 'edit',
        'issueId' => $issueId,
      ];
    } else {
      $vars = [
        'action' => 'add',
      ];
    }

    $form = [];
    $form += $this->instance->getIssueForm($form_state, $vars);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // Validate submitted form data.
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    if (empty($this->instance) || is_null($this->instance)) {
      $this->instance = \Drupal::service('plugin.manager.git_issues')->createInstance($this->activePlugin);
    }

    $this->instance->submitIssueForm($form_state);

    if ($form_state->get('action') == 'add') {
      $url = Url::fromRoute('git_issues.issues');
      $form_state->setRedirectUrl($url);
    }

  }

}
