<?php

namespace Drupal\git_issues\Form;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 *
 */
class GitIssuesSettingsForm extends ConfigFormBase {

  /**
   * Plugin instance.
   *
   * @var string
   */
  private $instance;

  /**
   * Active plugin name.
   *
   * @var string
   */
  protected $activePlugin;

  /**
   * Config instance.
   *
   * @var string
   */
  protected $gitSettings;

  /**
   * Constructs a GitIssuesSettingsForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactory $config_factory
   *   The config service.
   */
  public function __construct(ConfigFactory $config_factory) {
    $this->gitSettings = \Drupal::config('git_issues.settings');

    $this->activePlugin = $this->gitSettings->get('plugins.active');
    $this->activePlugin = (empty($this->activePlugin) && is_null($this->activePlugin)) ? 'gitlab' : $this->activePlugin;

    $this->instance = \Drupal::service('plugin.manager.git_issues')->createInstance($this->activePlugin);

    parent::__construct($config_factory);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    /** @var \Drupal\Core\Config\ConfigFactory $config */
    $config = $container->get('config.factory');
    return new static($config);
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'git_issues_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $pluginDefinitions = \Drupal::service('plugin.manager.git_issues')->getDefinitions();

    $form = [];
    $options = [];

    foreach ($pluginDefinitions as $plugin) {
      $options[$plugin['id']] = $plugin['git_label'];
    }

    // Fixed part of form that enables to chose plugin.
    $form['plugins'] = [
      '#type' => 'radios',
      '#title' => $this->t('Available plugins'),
      '#options' => $options,
      '#attributes' => ['name' => 'plugins'],
      '#default_value' => $this->activePlugin,
    ];

    $form += $this->instance->getSettingsForm();

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values['plugins'] = [
      'plugins' => $form_state->getValue('plugins'),
    ];

    \Drupal::configFactory()->getEditable('git_issues.settings')
      ->set('plugins.active', $values['plugins']['plugins'])
      ->save();

    $this->instance->submitSettingsForm($form, $form_state);

  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'git_issues.settings',
    ];
  }

}
