<?php

namespace Drupal\git_issues\Plugin\GitIssues;

use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines the interface for git issues.
 */
interface GitIssuesPluginInterface extends PluginInspectionInterface {

  /**
   * Get project issues list.
   *
   * {@inheritdoc}
   *
   * @return array
   */
  public function getProjectIssues();

  /**
   * Get single issue.
   *
   * {@inheritdoc}
   *
   * @param $issueId
   *   Issue id.
   *
   * @return array
   */
  public function getIssue($issueId);

  /**
   * Change state of single issue.
   *
   * {@inheritdoc}
   *
   * @param $issueId
   *   Issue id.
   * @param $state
   *   Issue state.
   */
  public function issueChangeState($issueId, $state);

  /**
   * Post comment to an issue.
   *
   * {@inheritdoc}
   *
   * @param $issueId
   *   Issue id.
   */
  public function postIssueComment($issueId);

  /**
   * Retrieves the settings form of plugin.
   *
   * {@inheritdoc}
   *
   * @return array
   *   Returns form array.
   */
  public function getSettingsForm();

  /**
   * Submit the settings form of plugin.
   *
   * {@inheritdoc}
   *
   * @param array $form
   *   $form array.
   * @param $form_state
   *   FormStateInterface object.
   */
  public function submitSettingsForm(array $form, FormStateInterface $form_state);

  /**
   * Retrieves the add/edit form of single issue.
   *
   * {@inheritdoc}
   *
   * @param array $form
   *   $form array.
   * @param $form_state
   *   FormStateInterface object.
   *
   * @return array
   *   Returns form array.
   */
  public function getIssueForm(FormStateInterface $form_state, array $vars);

  /**
   * Retrieves the single issue add/edit form.
   *
   * {@inheritdoc}
   *
   * @param $form_state
   *   FormStateInterface object.
   */
  public function submitIssueForm(FormStateInterface $form_state);

}
